/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * This file is part of SableCC.                             *
 * See the file "LICENSE" for copyright information and the  *
 * terms and conditions for copying, distribution and        *
 * modification of SableCC.                                  *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

package org.sablecc.sablecc;

import org.sablecc.sablecc.analysis.*;
import org.sablecc.sablecc.node.*;
import java.util.*;
import java.io.*;

public class AlternativeElementTypes extends DepthFirstAdapter
{
  private Map<String, String> altElemTypes = new HashMap<>();

  private ResolveIds ids;
  private String currentAlt;

  public AlternativeElementTypes(ResolveIds ids)
  {
    this.ids = ids;
  }

  public Map<String, String> getMapOfAltElemType()
  {
    return altElemTypes;
  }

  @Override
  public void caseAAst(AAst node)
  {}

  @Override
  public void caseAProd(final AProd production)
  {
    PAlt[] temp = production.getAlts().toArray(new PAlt[0]);
    for(PAlt alt : temp)
    {
      alt.apply(this);
    }
  }

  @Override
  public void caseAAlt(AAlt node)
  {
    currentAlt = ids.names.get(node);
    PElem[] temp = node.getElems().toArray(new PElem[0]);
    for(PElem elem : temp)
    {
      elem.apply(this);
    }
  }

  @Override
  public void inAElem(AElem node)
  {
    String elemType = ids.elemTypes.get(node);

    if(node.getElemName() != null)
    {
      altElemTypes.put(currentAlt+"."+node.getElemName().getText(), elemType );
    }
    else
    {
      altElemTypes.put(currentAlt+"."+node.getId().getText(), elemType );
    }
  }
}
